@@ -1,6 +1,6 @@
 /*
  * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@onda.com.br
+ * Mar/98 - Pedro L Orso - orso@brturbo.com
  */
 
 #include "include/conf.h"
@@ -27,6 +27,8 @@ void authfail_report(const char *dirname, int debug, const char *outdir, char *B
    char *str;
    int  z=0;
 
+   if(strlen(DataFile) > 0) return;
+
    ouser[0]='\0';
 
    sprintf(tmp4,"%s/authfail.log.unsort",TempDir);
@@ -154,9 +156,9 @@ void authfail_report(const char *dirname, int debug, const char *outdir, char *B
          } else strcpy(name,user);
       } else strcpy(name,user);
 
-      sprintf(html2,"<tr><td bgcolor=%s><font size=%s>%s</font></td>
-			<td bgcolor=%s><font size=%s>%s</font></td>
-			<td bgcolor=%s><font size=%s>%s-%s</font></td>
+      sprintf(html2,"<tr><td bgcolor=%s><font size=%s>%s</font></td> \
+			<td bgcolor=%s><font size=%s>%s</font></td> \
+			<td bgcolor=%s><font size=%s>%s-%s</font></td> \
 			<td bgcolor=%s><font size=%s><a href=\"%s\">%s</a></font></td></th>\n",
 			TxBgColor,FontSize,name,
 			TxBgColor,FontSize,ip,
@@ -167,11 +169,12 @@ void authfail_report(const char *dirname, int debug, const char *outdir, char *B
 
    fputs("</table>\n",fp_ou);
 
-   zdate(ftime, DateFormat);
-   sprintf(html,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",	\
-		text[108],URL,PGM,VERSION,text[109],ftime);
-   fputs(html,fp_ou);
-   fputs("</html>\n",fp_ou);
+   if(strcmp(ShowSargInfo,"yes") == 0) {
+      zdate(ftime, DateFormat);
+      sprintf(html,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n", text[108],URL,PGM,VERSION,text[109],ftime);
+      fputs(html,fp_ou);
+      fputs("</html>\n",fp_ou);
+   }
 
    fclose(fp_in);
    fclose(fp_ou);
