@@ -1,6 +1,6 @@
 #include "include/conf.h"
 
-void decomp(char *arq, char *zip)
+void decomp(char *arq, char *zip, char *tmp)
 {
 
    char cmd[1024];
@@ -11,13 +11,23 @@ void decomp(char *arq, char *zip)
       exit(1);
    }
 
-   if(strstr(arq,".gz") != 0) {
-      sprintf(cmd,"%s: %s (gzip)",text[62],arq);
+   if(strstr(arq,".gz") !=0) {
+      sprintf(cmd,"%s: %s > %s/sarg-file.in (zcat)",text[62],arq,tmp);
       debuga(cmd);
-      sprintf(cmd,"gzip -d %s",arq);
+      sprintf(cmd,"zcat %s > %s/sarg-file.in",arq,tmp);
       system(cmd);
-      arq[strlen(arq)-3]='\0';
-      strcpy(zip,"gzip");
+      strcpy(zip,"zcat");
+      sprintf(arq,"%s/sarg-file.in",tmp);
+      return;
+   }
+
+   if(strstr(arq,".bz2") != 0) {
+      sprintf(cmd,"%s: %s > %s/sarg-file.in (bzcat)",text[62],arq,tmp);
+      debuga(cmd);
+      sprintf(cmd,"bzcat %s > %s/sarg-file.in",arq,tmp);
+      system(cmd);
+      strcpy(zip,"zcat");
+      sprintf(arq,"%s/sarg-file.in",tmp);
       return;
    }
 
