@@ -1,6 +1,6 @@
 /*
  * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@onda.com.br
+ * Mar/98 - Pedro L Orso - orso@brturbo.com
  */
 
 #include "include/conf.h"
@@ -82,8 +82,7 @@ void gen_denied_report(const char *dirname, int debug, const char *outdir, char
    sprintf(url,"<tr><th align=center><b><font color=%s size=+1>%s</font></b></th></tr>\n",TiColor,Title);
    fputs(url,fp_ou);
 
-   sprintf(url,"<tr><td align=center bgcolor=%s><font size=%s color=%s>%s: %s</font></td></tr>\n",	\
-		HeaderBgColor,FontSize,HeaderColor,text[89],periodo);
+   sprintf(url,"<tr><td align=center bgcolor=%s><font size=%s color=%s>%s: %s</font></td></tr>\n", HeaderBgColor,FontSize,HeaderColor,text[89],periodo);
    fputs(url,fp_ou);
    sprintf(url,"<tr><th bgcolor=%s align=center><font size=%s color=red>%s</font>		\
 		 <font size=%s>%s</font></th></tr>\n",	\
@@ -149,9 +148,9 @@ void gen_denied_report(const char *dirname, int debug, const char *outdir, char
          } else strcpy(name,user);
       } else strcpy(name,user);
 
-      sprintf(html2,"<tr><td bgcolor=%s><font size=%s>%s</font></td>
-			<td bgcolor=%s><font size=%s>%s</font></td>
-			<td bgcolor=%s><font size=%s>%s-%s</font></td>
+      sprintf(html2,"<tr><td bgcolor=%s><font size=%s>%s</font></td> \
+			<td bgcolor=%s><font size=%s>%s</font></td> \
+			<td bgcolor=%s><font size=%s>%s-%s</font></td> \
 			<td bgcolor=%s><font size=%s><a href=\"%s\">%s</a></font></td></th>\n",
 			TxBgColor,FontSize,name,
 			TxBgColor,FontSize,ip,
@@ -162,10 +161,11 @@ void gen_denied_report(const char *dirname, int debug, const char *outdir, char
 
    fputs("</table>\n",fp_ou);
 
-   zdate(ftime, DateFormat);
-   sprintf(html,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",	\
-		text[108],URL,PGM,VERSION,text[109],ftime);
-   fputs(html,fp_ou);
+   if(strcmp(ShowSargInfo,"yes") == 0) {
+      zdate(ftime, DateFormat);
+      sprintf(html,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n", text[108],URL,PGM,VERSION,text[109],ftime);
+      fputs(html,fp_ou);
+   }
    fputs("</html>\n",fp_ou);
 
    fclose(fp_in);
