@@ -56,10 +56,16 @@ long long int my_atoll (const char *nptr);
 FILE *fp_tt; 
 
 char buf[8192];
+char url[8192];
+char urly[8192];
+char user[MAXLEN];
 char msg[1024];
+char per_hour[128];
+char tmp3[MAXLEN];
 char tmp4[MAXLEN];
 char tmp5[MAXLEN];
 char tmp6[MAXLEN];
+char parse_out[MAXLEN];
 char arqtt[MAXLEN];
 char html[MAXLEN];
 char datestimes[MAXLEN];
@@ -131,12 +137,34 @@ char IncludeUsers[MAXLEN];
 char ExcludeString[MAXLEN];
 char SuccessfulMsg[5];
 char TopUserFields[255];
+char UserReportFields[255];
+char DataFile[MAXLEN];
+char DataFileDelimiter[3];
+char DataFileFields[MAXLEN];
+char SiteUserTimeDateType[10];
+char ShowReadStatistics[5];
+char IndexSortOrder[5];
+char SquidGuardLogPath[MAXLEN];
+char ShowSargInfo[5];
+char ParsedOutputLog[MAXLEN];
+char ParsedOutputLogCompress[255];
+char DisplayedValues[20];
+char hbc1[30];
+char hbc2[30];
+char hbc3[30];
+char hbc4[30];
+char hbc5[30];
+char hbc6[30];
+char hbc7[30];
+char hbc8[30];
+char hbc9[30];
+char hbc10[30];
 
 char *excludecode;
 char *userfile;
 char *str;
 char *str2;
-char text[130][255];
+char text[200][255];
 char val1[255];
 char val2[255];
 char val3[255];
@@ -160,10 +188,20 @@ char user2[MAXLEN];
 int  excode;
 int  denied_count;
 int  authfail_count;
+int  squidguard_count;
 int  limit_flag;
 int  z1, z2;
 int  ttopen;
 int  ind2;
+int  dataonly;
+int  langcode;
 
 long long int twork;
 long long int twork2;
+
+typedef struct
+{ int list[ 24 ];
+  int len;
+} numlist;
+
+int getnumlist( char *, numlist *, const int, const int );
