@@ -1,6 +1,6 @@
 /*
  * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@onda.com.br
+ * Mar/98 - Pedro L Orso - orso@brturbo.com
  */
 
 #include "include/conf.h"
@@ -24,6 +24,7 @@ void index_only(const char *dirname, int debug)
    }
 
    (void)closedir( dirp );
+   (void)rewinddir( dirp );
 
    return;
 }
