@@ -1,6 +1,6 @@
 /*
  * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@onda.com.br
+ * Mar/98 - Pedro L Orso - orso@brturbo.com
  */
 
 #include "include/conf.h"
@@ -25,6 +25,10 @@ void language_load(char *language)
       getword(warea,buf,'"');
       getword(warea,buf,'"');
       strcpy(text[record],warea);
+
+      if(langcode)
+      printf("%d %s\n",record,warea);
+
       record++;
    }
 
