@@ -1,6 +1,6 @@
 /*
  * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@onda.com.br
+ * Mar/98 - Pedro L Orso - orso@brturbo.com
  */
 
 #include "include/conf.h"
@@ -44,6 +44,7 @@ void mklastlog(char *outdir, int debug)
    }
 
    (void)closedir( dirp );
+   (void)rewinddir( dirp );
    fclose(fp_ou);
    
    sprintf(buf,"sort -n -k 1,1 -o %slastlog %s",outdir,temp);
