@@ -1,6 +1,6 @@
 /*
  * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@onda.com.br
+ * Mar/98 - Pedro L Orso - orso@brturbo.com
  */
 
 #include "include/conf.h"
@@ -9,17 +9,28 @@ char *userfile;
 char *excludefile;
 char *excludeuser;
 
+//int m_wdays[ 7 ] = { 0, 1, 2, 3, 4, 5, 6 };
+//int mwd_limit = 7;
+//int m_hours[ 24 ] = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
+//			13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23 };
+//int mh_limit = 24;
+
+numlist weekdays = { { 0, 1, 2, 3, 4, 5, 6 }, 7 };
+numlist hours = { { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
+             13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23 }, 24 };
+
 void getusers(char *pwdfile, int debug);
 void gethexclude(char *hexfile, int debug);
 void getuexclude(char *uexfile, int debug);
 void ttx(char *user);
+int compar( const void *, const void * );
 
 int main(argc,argv)
    int argc;
    char *argv[];
 {
 
-   FILE *fp_in = NULL, *fp_ou = NULL, *fp_denied, *fp_usr, *fp_authfail;
+   FILE *fp_in = NULL, *fp_ou = NULL, *fp_denied, *fp_usr, *fp_authfail, *fp_log;
 
    extern int optind;
    extern int optopt;
@@ -33,9 +44,6 @@ int main(argc,argv)
    char msg[MAXLEN];
    char tam[255];
    char fun[255];
-   char url[8192];
-   char urly[8192];
-   char user[MAXLEN];
    char wuser[MAXLEN]; 
    char code[MAXLEN];
    char code2[MAXLEN];
@@ -53,6 +61,7 @@ int main(argc,argv)
    char us[50];
    char date[255];
    char arq[255];
+   char arq_log[255];
    char warq[255][255];
    char addr[MAXLEN];
    char hm[6];
@@ -62,6 +71,7 @@ int main(argc,argv)
    char hexclude[MAXLEN];
    char csort[MAXLEN]; 
    char tbuf[128];
+   char tbuf2[128];
    char email[MAXLEN];
    char zip[20];
    char *str;
@@ -76,7 +86,8 @@ int main(argc,argv)
    int  userip=0;
    int  indexonly=0;
    int  ch;
-   int  x, l;
+   int  d;
+   int  x, l, i;
    int  errflg=0;
    int  debug=0;
    int  debugz=0;
@@ -91,6 +102,8 @@ int main(argc,argv)
    int  idata=0;
    int  narq=0;
    int  iarq=0;
+   int  sarglog=0;
+   int  exstring=0;
    long totregsl=0; 
    long totregsg=0;
    long totregsx=0;
@@ -99,6 +112,8 @@ int main(argc,argv)
    time_t tt;
    struct tm *t;
    unsigned long nreg=0;
+   off_t recs1=0;
+   unsigned long recs2=0;
 
    BgImage[0]='\0';
    LogoImage[0]='\0';
@@ -118,7 +133,7 @@ int main(argc,argv)
    ReportType[0]='\0';
    UserTabFile[0]='\0';
 
-   strcpy(AccessLog,"/usr/local/squid/logs/access.log");
+   strcpy(AccessLog,"/usr/local/squid/var/logs/access.log");
    sprintf(ExcludeCodes,"%s/exclude_codes",SYSCONFDIR);
    strcpy(BgColor,"white");
    strcpy(TxColor,"black");
@@ -158,6 +173,16 @@ int main(argc,argv)
    strcpy(PrivacyStringColor,"blue");
    strcpy(SuccessfulMsg,"yes");
    strcpy(TopUserFields,"NUM DATE_TIME USERID CONNECT BYTES %BYTES IN-CACHE-OUT USED_TIME MILISEC %TIME TOTAL AVERAGE");
+   strcpy(UserReportFields,"CONNECT BYTES %BYTES IN-CACHE-OUT USED_TIME MILISEC %TIME TOTAL AVERAGE");
+   strcpy(DataFileDelimiter,";");
+   strcpy(DataFileFields,"user;date;time;url;connect;bytes;in_cache;out_cache;elapsed");
+   strcpy(SiteUserTimeDateType,"table");
+   strcpy(ShowReadStatistics,"no");
+   strcpy(IndexSortOrder,"D");
+   strcpy(ShowSargInfo,"yes");
+   strcpy(ParsedOutputLog,"no");
+   strcpy(ParsedOutputLogCompress,"/bin/gzip");
+   strcpy(DisplayedValues,"bytes");
 
    dia[0]='\0';
    mes[0]='\0';
@@ -181,12 +206,16 @@ int main(argc,argv)
    email[0]='\0';
    zip[0]='\0';
    UserInvalidChar[0]='\0';
+   DataFile[0]='\0';
+
    excode=0;
    denied_count=0;
    authfail_count=0;
+   squidguard_count=0;
 
    bzero(IncludeUsers, MAXLEN);
    bzero(ExcludeString, MAXLEN);
+   bzero(SquidGuardLogPath, MAXLEN);
 
    for(x=0; x<=254; x++) 
       warq[x][0]='\0';
@@ -194,7 +223,7 @@ int main(argc,argv)
    language_load(language);
    strcpy(Title,text[88]);
 
-   while((ch = getopt(argc, argv, "a:b:c:d:e:f:g:u:l:o:r:s:t:w:hijmnpxz")) != -1){
+   while((ch = getopt(argc, argv, "a:b:c:d:e:f:g:u:l:o:r:s:t:w:hijmnpxyz")) != -1){
       switch(ch)
       {
          case 'a':
@@ -261,6 +290,9 @@ int main(argc,argv)
          case 'x':
             debug++;
             break;
+         case 'y':
+            langcode++;
+            break;
          case 'z':
             debugz++;
             break;
@@ -335,8 +367,16 @@ int main(argc,argv)
       fprintf(stderr, "SARG:\n");
    }
 
+
+   dataonly=0;
+   if(DataFile[0] != '\0');
+      dataonly++;
+   
    str2=(char *)subs(TopUserFields,"%BYTES","SETYB");
    strcpy(TopUserFields,str2);
+   
+   str2=(char *)subs(UserReportFields,"%BYTES","SETYB");
+   strcpy(UserReportFields,str2);
 
    if(!narq) {
       strcpy(warq[0],AccessLog);
@@ -398,9 +438,6 @@ int main(argc,argv)
    if(strcmp(UserIp,"yes") == 0)
       userip++;
 
-   if(strcmp(UserIp,"yes") == 0)
-      userip++;
-
    if(strlen(MaxElapsed)>1)
       max_elapsed=atol(MaxElapsed);
 
@@ -450,8 +487,8 @@ int main(argc,argv)
 
    strcat(tmp2,"/sarg.log");
 
-   strcpy(tmp3,tmp2);
-   strcat(tmp3,".unsort");
+   sprintf(tmp3,"mkdir -p %s/sarg",tmp);
+   system(tmp3);
    strcat(tmp4,"/denied.log.unsort");
    strcat(tmp5,"/denied.log");
    strcat(tmp6,"/authfail.log.unsort");
@@ -586,16 +623,12 @@ int main(argc,argv)
       fclose(fp_usr);
    }
 
-   if((fp_ou=fopen(tmp3,"w"))==NULL) {
-     fprintf(stderr, "%s: (log) %s: %s\n",argv[0],text[9],tmp3);
-     exit(1);
-   }
-
    while(narq--) {
       strcpy(arq,warq[iarq]);
       iarq++;  
 
-   decomp(arq,zip);
+   strcpy(arqtt,arq);
+   decomp(arq,zip,tmp);
    if(debug) {
       sprintf(msg, "%s: %s",text[7],arq);
       debuga(msg);
@@ -605,6 +638,28 @@ int main(argc,argv)
      fprintf(stderr, "%s: (log) %s: %s\n",argv[0],text[8],arq);
      exit(1);
    }
+   fgets(bufz,sizeof(bufz),fp_in);
+   if(strncmp(bufz,"*** SARG Log ***",16) == 0) {
+      getword(val2,arqtt,'-');
+      getword(val2,arqtt,'_');
+      getword(val3,arqtt,'-');
+      getword(val3,arqtt,'_');
+      sprintf(periodo,"%s-%s",val2,val3);
+      sarglog=1;
+   } else lseek(fileno(fp_in), 0, 0);
+
+   if(strcmp(ParsedOutputLog, "no") != 0 && !sarglog) {
+      if(access(ParsedOutputLog,R_OK) != 0) {
+         sprintf(csort,"mkdir -p %s",ParsedOutputLog);
+         system(csort);
+      }
+      sprintf(arq_log,"%s/sarg_temp.log",ParsedOutputLog);
+      if((fp_log=fopen(arq_log,"w"))==NULL) {
+        fprintf(stderr, "%s: (log) %s: %s\n",argv[0],text[8],arq_log);
+        exit(1);
+      }
+      fputs("*** SARG Log ***\n",fp_log);
+   }
 
    if(strstr(ReportType,"denied") != 0) {
       if((fp_denied=fopen(tmp4,"w"))==NULL) {
@@ -613,32 +668,59 @@ int main(argc,argv)
       }
    }
 
-   if(strstr(ReportType,"denied") != 0 || strstr(ReportType,"auth_failures") != 0) {
-      if((fp_authfail=fopen(tmp6,"w"))==NULL) {
-         fprintf(stderr, "%s: (log) %s: %s\n",argv[0],text[45],tmp6);
-         exit(1);
+   if(DataFile[0]=='\0') {
+      if(strstr(ReportType,"denied") != 0 || strstr(ReportType,"auth_failures") != 0) {
+         if((fp_authfail=fopen(tmp6,"w"))==NULL) {
+            fprintf(stderr, "%s: (log) %s: %s\n",argv[0],text[45],tmp6);
+            exit(1);
+         }
       }
    }
 
+   if(debug) {
+      recs1=0;
+      while(fgets(bufz,sizeof(bufz),fp_in)!=NULL)
+         recs1++;
+      lseek(fileno(fp_in), 0, 0);
+   }
+   
    while(fgets(bufz,sizeof(bufz),fp_in)!=NULL) {
+	recs2++;
+	if(strcmp(ShowReadStatistics,"yes") == 0) 
+	   printf("SARG: Records in file=%d Reading=%d Rest=%d\r",recs1,recs2,recs1-recs2);
         if(!bufz[0]) continue;
         if(strstr(bufz,"HTTP/0.0") != 0) continue;
+        if(strstr(bufz,"logfile turned over") != 0) continue;
         if(bufz[0] == ' ') continue;
-        if(strlen(bufz) < 30) continue;
+        if(strlen(bufz) < 58) continue;
 
-	// exclude_string
-	if(strlen(ExcludeString) > 0) {
-	   strcpy(warea,bufz);
-	   strcpy(html,ExcludeString);
-	   while(strstr(html,":") != 0) {
+        // Record only hours usage which is required
+        tt = (time_t) strtoul( bufz, NULL, 10 );
+        t = localtime( &tt );
+
+        if( bsearch( &( t -> tm_wday ), weekdays.list, weekdays.len,
+                                        sizeof( int ), compar ) == NULL )
+          continue;
+
+        if( bsearch( &( t -> tm_hour ), hours.list, hours.len,
+                                        sizeof( int ), compar ) == NULL )
+          continue;
+
+        // exclude_string
+        exstring=0;
+        if(strlen(ExcludeString) > 0) {
+           strcpy(warea,bufz);
+           strcpy(html,ExcludeString);
+           while(strstr(html,":") != 0) {
               getword(val1,html,':');
               if((str=(char *) strstr(warea,val1)) != (char *) NULL )
-	         continue;;
-	   }
+                 exstring++;
+           }
            if((str=(char *) strstr(warea,html)) != (char *) NULL )
-	         continue;;
-	}
-        
+                 exstring++;
+        }
+        if(exstring) continue;
+
         strcpy(bufy,bufz);
         if ((str = strchr(bufz, '\n')) != NULL)
            *str = '\0';          /* strip \n */       
@@ -648,34 +730,35 @@ int main(argc,argv)
         if(debugm)
        	   printf("BUF=%s\n",bufz);
 
-	getword(data,bufz,' ');
-        if((str=(char *) strstr(data, ".")) != (char *) NULL ) {
-           if((str=(char *) strstr(str+1, ".")) != (char *) NULL ) {
-	      strcpy(ip,data);
-	      strcpy(elap,"0");
-	      getword(user,bufz,' ');
-	      getword(none,bufz,' ');
-	      getword(data,bufz,']');
-	      getword(fun,bufz,'"');
-	      getword(fun,bufz,' ');
-	      getword(url,bufz,'"');
-              getword(code2,bufz,' ');
-              getword(code2,bufz,' ');
-              getword(tam,bufz,' ');
-              strcpy(code,bufz);
+        if(!sarglog) {
+           getword(data,bufz,' ');
+           if((str=(char *) strstr(data, ".")) != (char *) NULL ) {
+              if((str=(char *) strstr(str+1, ".")) != (char *) NULL ) {
+                 strcpy(ip,data);
+       	         strcpy(elap,"0");
+	         getword(user,bufz,' ');
+	         getword(none,bufz,' ');
+	         getword(data,bufz,']');
+	         getword(fun,bufz,'"');
+	         getword(fun,bufz,' ');
+	         getword(url,bufz,'"');
+                 getword(code2,bufz,' ');
+                 getword(code2,bufz,' ');
+                 getword(tam,bufz,' ');
+                 strcpy(code,bufz);
 
-              if ((str = strchr(code, ':')) != NULL)
-                 *str = '/'; 
+                 if ((str = strchr(code, ':')) != NULL)
+                    *str = '/'; 
 
-	      if(strcmp(tam,"\0") == 0)
-	         strcpy(tam,"0");
+	         if(strcmp(tam,"\0") == 0)
+	            strcpy(tam,"0");
 
-	      common++;
-	      common_log=1;
+	         common++;
+	         common_log=1;
+	      }
 	   }
-	}
 
-	if(!common) {
+	   if(!common) {
 	      getword(elap,bufz,' ');
 	      while(strcmp(elap,"") == 0)
 	         getword(elap,bufz,' ');
@@ -686,7 +769,18 @@ int main(argc,argv)
 	      getword(url,bufz,' ');
 	      getword(user,bufz,' ');
 	      squid_log=1;
-	}
+	   }
+        } else {
+	   getword(data,bufz,' ');
+	   getword(hora,bufz,' ');
+	   getword(user,bufz,' ');
+	   getword(ip,bufz,' ');
+	   getword(url,bufz,' ');
+	   getword(tam,bufz,' ');
+	   getword(code,bufz,' ');
+	   getword(elap,bufz,' ');
+	   getword(smartfilter,bufz,' ');
+        }
 
 	// include_users
 	if(strlen(IncludeUsers) > 0) {
@@ -742,40 +836,47 @@ int main(argc,argv)
            strcpy(url,w);
         }
 
-        if(!common) {
-           tt=atoi(data);
-           t=localtime(&tt);
+        if(!sarglog) {
+           if(!common) {
+              tt=atoi(data);
+              t=localtime(&tt);
 
-           if(strncmp(df,"u",1) == 0)
-	      strftime(tbuf, 127, "%Y%b%d", t);
-           if(strncmp(df,"e",1) == 0)
-	      strftime(tbuf, 127, "%d%b%Y", t);
-           if(strncmp(df,"w",1) == 0)
-	      strftime(tbuf, 127, "%Y.%U", t);
+              strftime(tbuf2, 127, "%H%M", t);
+              if(strncmp(df,"u",1) == 0)
+	         strftime(tbuf, 127, "%Y%b%d", t);
+              if(strncmp(df,"e",1) == 0)
+	         strftime(tbuf, 127, "%d%b%Y", t);
+              if(strncmp(df,"w",1) == 0)
+	         strftime(tbuf, 127, "%Y.%U", t);
 
-           strftime(dia, 127, "%d/%m/%Y", t);
-           strftime(wdata, 127, "%Y%m%d", t);
+              strftime(dia, 127, "%d/%m/%Y", t);
+              strftime(wdata, 127, "%Y%m%d", t);
           
-           idata=atoi(wdata);
+              idata=atoi(wdata);
 
-           if(strncmp(df,"u",1)==0)
-              strftime(dia, 127, "%m/%d/%Y", t);
-           sprintf(hora,"%02d:%02d:%02d",t->tm_hour,t->tm_min,t->tm_sec);
-	 } else {
-	   strcpy(wtemp,data+1);
-	   getword(data,wtemp,':');
-	   getword(hora,wtemp,' ');
-	   getword(dia,data,'/');
+              if(strncmp(df,"u",1)==0)
+                 strftime(dia, 127, "%m/%d/%Y", t);
+              sprintf(hora,"%02d:%02d:%02d",t->tm_hour,t->tm_min,t->tm_sec);
+	    } else {
+	      strcpy(wtemp,data+1);
+	      getword(data,wtemp,':');
+	      getword(hora,wtemp,' ');
+	      getword(dia,data,'/');
+	      getword(mes,data,'/');
+	      getword(ano,data,'/');
+
+              if(strcmp(df,"u") == 0)
+	         sprintf(tbuf,"%s%s%s",ano,mes,dia);
+              if(strcmp(df,"e") == 0)
+	         sprintf(tbuf,"%s%s%s",dia,mes,ano);
+	      builddia(dia,mes,ano,df,wdata);
+              idata=atoi(wdata);
+	   }
+        } else {
 	   getword(mes,data,'/');
-	   getword(ano,data,'/');
-
-           if(strcmp(df,"u") == 0)
-	      sprintf(tbuf,"%s%s%s",ano,mes,dia);
-           if(strcmp(df,"e") == 0)
-	      sprintf(tbuf,"%s%s%s",dia,mes,ano);
-	   builddia(dia,mes,ano,df,wdata);
-           idata=atoi(wdata);
-	}
+	   getword(dia,data,'/');
+	   strcpy(ano,data);
+        }
 
         if(debugm)
            printf("DATE=%s IDATA=%d DFROM=%d DUNTIL=%d\n",date,idata,dfrom,duntil);
@@ -864,7 +965,16 @@ int main(argc,argv)
               } else sprintf(smartfilter,"\"\"");
 
               sprintf(bufz, "%s %s %s %s %s %s %s %s %s\n",dia,hora,user,ip,url,tam,code,elap,smartfilter);
+              sprintf(tmp3,"%s/sarg/%s.unsort",tmp,user);
+              if((fp_ou=fopen(tmp3,"a"))==NULL) {
+                fprintf(stderr, "%s: (log) %s: %s\n",argv[0],text[9],tmp3);
+                exit(1);
+              }
               fputs(bufz,fp_ou);
+              if(strcmp(ParsedOutputLog, "no") != 0 && !sarglog)
+                 fputs(bufz,fp_log);
+
+              fclose(fp_ou);
 	      totregsg++;
 
               if(strstr(ReportType,"denied") != 0 || strstr(ReportType,"auth_failures") != 0) {
@@ -875,14 +985,16 @@ int main(argc,argv)
                  }
                  if(strstr(code,"DENIED/401") != 0 || strstr(code,"DENIED/407") != 0) {
                     sprintf(bufz, "%s %s %s %s %s\n",dia,hora,user,ip,urly);
-                    fputs(bufz,fp_authfail);
+                    if(fp_authfail)
+                       fputs(bufz,fp_authfail);
                     authfail_count++;
                  }
               }
        
-              if(!totper){
+              if(!totper && !sarglog){
 	         totper++;
                  sprintf(periodo,"%s-",tbuf);
+                 sprintf(per_hour,"%s-",tbuf2);
                  if(strlen(date)>0)
                     fixper(tbuf, periodo, cduntil);
                  if(debugz){
@@ -908,6 +1020,8 @@ int main(argc,argv)
    }
 
    if(debug) {
+      if(strcmp(ShowReadStatistics,"yes") == 0) 
+         printf("\n");
       sprintf(msg, "   %s: %ld, %s: %ld, %s: %ld",text[10],totregsl,text[11],totregsg,text[68],totregsx);
       debuga(msg);
   
@@ -919,12 +1033,18 @@ int main(argc,argv)
  
       if((!common_log) && (squid_log))
          debuga(text[14]);
+
+      if(sarglog)
+         debuga(text[124]);
  
-      if((!common_log) && (!squid_log)) {
-         fprintf(stderr, "SARG: %s\n",text[15]);
+      if((!common_log) && (!squid_log) && (!sarglog)) {
+         if(!totregsg) {
+            fprintf(stderr, "SARG: %s\n",text[16]);
+            fprintf(stderr, "SARG: %s\n",text[21]);
+	 } else fprintf(stderr, "SARG: %s\n",text[15]);
          bzero(msg,sizeof(msg));
          fclose(fp_in);
-         fclose(fp_ou);
+//         fclose(fp_ou);
          if(fp_denied)
             fclose(fp_denied);
          if(fp_authfail)
@@ -942,7 +1062,7 @@ int main(argc,argv)
       fprintf(stderr, "SARG: %s\n",text[16]);
       fprintf(stderr, "SARG: %s\n",text[21]);
       fclose(fp_in);
-      fclose(fp_ou);
+//      fclose(fp_ou);
       if(fp_denied)
          fclose(fp_denied);
       if(fp_authfail)
@@ -950,8 +1070,10 @@ int main(argc,argv)
       exit(0);
    }
 
-   if(date[0] == '\0')
+   if(date[0] == '\0' && !sarglog) {
       strcat(periodo,tbuf);
+      strcat(per_hour,tbuf2);
+   }
 
    if(debugz){
       debugaz("data",dia);
@@ -965,22 +1087,33 @@ int main(argc,argv)
    }
 
    fclose(fp_in);
-   fclose(fp_ou);
+//   fclose(fp_ou);
    if(fp_denied)
       fclose(fp_denied);
    if(fp_authfail)
       fclose(fp_authfail);
 
-   if(debug){
-     sprintf(msg,"Sort: %s %s %s",text[18],tmp,text[19]);
-     debuga(msg);
-     sprintf(msg, "%s: %s",text[20],tmp2);
-     debuga(msg);
-   }
+   if(strcmp(ParsedOutputLog, "no") != 0 && !sarglog) {
+      fclose(fp_log); 
+      strcpy(val1,periodo);
+      getword(val2,val1,'-');
+      getword(val3,per_hour,'-');
+      sprintf(val4,"%s/sarg-%s_%s-%s_%s.log",ParsedOutputLog,val2,val3,val1,per_hour);
+      rename(arq_log,val4);
+      strcpy(arq_log,val4);
 
-   sprintf(csort,"sort -T %s -k 3,3 -k 5,5 -o %s %s", tmp, tmp2, tmp3);
-   system(csort);
-   unlink(tmp3);
+      if(strcmp(ParsedOutputLogCompress,"nocompress") != 0) {
+         sprintf(val1,"%s %s",ParsedOutputLogCompress,arq_log);
+         system(val1);
+      }
+
+      if(debug) {
+         sprintf(msg,"%s %s",text[123],arq_log);
+         debuga(msg);
+      }
+   }
+ 
+   sort_users_log(tmp, debug);
 
    if(strstr(ReportType,"denied") != 0) {
       sprintf(csort,"sort -T %s -k 3,3 -k 5,5 -o %s %s", tmp, tmp5, tmp4);
@@ -988,18 +1121,26 @@ int main(argc,argv)
       unlink(tmp4);
    }
 
-   gerarel(tmp2,debug,periodo,debugz,iprel,outdir,addr,site,us,userip,email,wtemp2,BgColor,TxColor, TxBgColor,TiColor,LogoImage,LogoText,LogoTextColor,Width,Height,Title,BgImage,FontFace,HeaderColor,HeaderBgColor,FontSize,TempDir,Ip2Name,TopuserSortField,UserSortField,TopuserSortOrder,UserSortOrder,uagent,DateFormat,indexonly,PerUserLimitFile,PerUserLimit);
+   report_gen:
+   if(strlen(DataFile) > 0)
+      data_file(tmp2,debug,periodo,debugz,iprel,outdir,addr,site,us,userip,email,wtemp2,BgColor,TxColor, TxBgColor,TiColor,LogoImage,LogoText,LogoTextColor,Width,Height,Title,BgImage,FontFace,HeaderColor,HeaderBgColor,FontSize,TempDir,Ip2Name,TopuserSortField,UserSortField,TopuserSortOrder,UserSortOrder,uagent,DateFormat,indexonly,PerUserLimitFile,PerUserLimit);
+   else
+      gerarel(tmp,debug,periodo,debugz,iprel,outdir,addr,site,us,userip,email,wtemp2,BgColor,TxColor, TxBgColor,TiColor,LogoImage,LogoText,LogoTextColor,Width,Height,Title,BgImage,FontFace,HeaderColor,HeaderBgColor,FontSize,TempDir,Ip2Name,TopuserSortField,UserSortField,TopuserSortOrder,UserSortOrder,uagent,DateFormat,indexonly,PerUserLimitFile,PerUserLimit);
 
    unlink(tmp2);
    if(strstr(ReportType,"denied") != 0)
       unlink(tmp5);
  
-   if(strlen(zip) > 0)
-      recomp(arq, zip);
+   if((strlen(zip) > 0 && strcmp(zip,"zcat") !=0)) {
+      recomp(arq, zip); }
+//   else  unlink(arq);
 
    if(debug)
       debuga(text[21]);
 
+   sprintf(csort,"rm -rf %s",tmp);
+   system(csort);
+
    exit(0);
 
 }
@@ -1036,7 +1177,7 @@ void getusers(char *pwdfile, int debug)
    bzero(userfile,nreg);
    sprintf(userfile,":");
 
-   while(fgets(buf,300,fp_usr)!=NULL){
+   while(fgets(buf,255,fp_usr)!=NULL){
      getword(user,buf,':');
      strncat(userfile,user,strlen(user));
      strncat(userfile,":",1);
@@ -1076,7 +1217,7 @@ void gethexclude(char *hexfile, int debug)
 
    bzero(excludefile,nreg+11);
 
-   while(fgets(buf,300,fp_ex)!=NULL){
+   while(fgets(buf,255,fp_ex)!=NULL){
      if(strstr(buf,"#") != 0)
         continue;
      buf[strlen(buf)-1]='\0';
@@ -1120,7 +1261,7 @@ void getuexclude(char *uexfile, int debug)
 
    bzero(excludeuser,nreg+11);
 
-   while(fgets(buf,300,fp_ex)!=NULL){
+   while(fgets(buf,255,fp_ex)!=NULL){
      if(strstr(buf,"#") != 0)
         continue;
      buf[strlen(buf)-1]='\0';
