@@ -1,6 +1,6 @@
 /*
  * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@onda.com.br
+ * Mar/98 - Pedro L Orso - orso@brturbo.com
  */
 
 #include "include/conf.h"
@@ -17,13 +17,13 @@ void grava_SmartFilter(char *dirname, char *user, char *ip, char *data, char *ho
 void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, char* outdir, char *addr, char *site, char *us, int userip, char *email, char *temp2, char *BgColor, char *TxColor, char *TxBgColor, char *TiColor, char *LogoImage, char *LogoText, char *LogoTextColor, char *Width, char *Height, char *Title, char *BgImage, char *FontFace, char *HeaderColor, char *HeaderBgColor, char *FontSize, char *TempDir, char *Ip2Name, char *TopuserSortField, char *UserSortField, char *TopuserSortOrder, char *UserSortOrder, char *UserAgentLog, char *DateFormat, int indexonly, char *PerUserLimitFile, char *PerUserLimit)
 {
 
-   FILE *fp_in;
+   FILE *fp_in, *fp_ou;
 
    char accdia[11], acchora[9], accuser[MAXLEN], accip[MAXLEN], accurl[MAXLEN], accbytes[12], accelap[10];
    char oldaccdia[11], oldacchora[9], oldaccip[MAXLEN], wdir[MAXLEN], per1[MAXLEN];
    char dirname[MAXLEN], wdirname[MAXLEN], oldurl[MAXLEN], oldaccuser[MAXLEN];
-   char olduser[MAXLEN], oldmsg[50], acccode[50], oldaccelap[10], oldacccode[50];
-   char ipantes[MAXLEN], nameantes[MAXLEN]; 
+   char olduser[MAXLEN], oldmsg[50], acccode[50], oldaccelap[10], oldacccode[50], user[MAXLEN];
+   char ipantes[MAXLEN], nameantes[MAXLEN], wdname[MAXLEN], wname2[MAXLEN]; 
    char accsmart[MAXLEN];
    int  smartfilter=0;
    char wcrc[50];
@@ -35,6 +35,8 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
    long long int incache=0;
    long long int oucache=0;
    char *s;
+   DIR *dirp;
+   struct dirent *direntp;
 
    ipantes[0]='\0';
    nameantes[0]='\0';
@@ -58,99 +60,114 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
    }
 
    olduser[0]='\0';
+   strncat(tmp,"/sarg",5);
 
-   if((fp_in=fopen(tmp,"r"))==NULL){
-      fprintf(stderr, "SARG: (report) %s: %s\n",text[45],tmp);
-      exit(1);
-   }
+   dirp = opendir(tmp);
+   while ( (direntp = readdir( dirp )) != NULL ) {
+      if(strstr(direntp->d_name,".log") == 0)
+         continue;
+      sprintf(tmp3,"%s/%s",tmp,direntp->d_name);
 
-   ttopen=0;
-   bzero(html_old, MAXLEN);
-
-   while(fgets(buf,sizeof(buf),fp_in)!=NULL) {
-      getword(accdia,buf,' ');
-      getword(acchora,buf,' ');
-      getword(accuser,buf,' ');
-      getword(accip,buf,' ');
-      getword(accurl,buf,' ');
-      getword(accbytes,buf,' ');
-      getword(acccode,buf,' ');
-      getword(accelap,buf,' ');
-      getword(accsmart,buf,' ');
-      getword(accsmart,buf,'"');
-
-      if(strlen(accsmart) > 0) {
-         smartfilter++;
-         strcpy(wdirname,dirname);
-         grava_SmartFilter(wdirname,accuser,accip,accdia,acchora,accurl,accsmart);
+      if((fp_in=fopen(tmp3,"r"))==NULL){
+         fprintf(stderr, "SARG: (report) %s: %s\n",text[45],tmp);
+         exit(1);
       }
-
-      if(strcmp(Ip2Name,"yes") == 0) {
-         if(strcmp(accip,ipantes) != 0) {
-            strcpy(ipantes,accip);
-            ip2name(accip);
-            strcpy(nameantes,accip);
-         } else strcpy(accip,nameantes);
+    
+      strcpy(wdname,direntp->d_name);
+      strip_prefix:
+      getword(wname2,wdname,'.');
+      strcat(user,wname2);
+   
+      if(strcmp(wdname,"log") !=0) {
+         strcat(user,".");
+         goto strip_prefix;
       }
-     
-      if(strcmp(olduser,accuser) != 0){
-         strcpy(wdirname,dirname);
-	 criatmp(accuser,wdirname,debug,indexonly);
-	 criatmp_hora(accuser,wdirname,indexonly);
-         strcpy(olduser,accuser);
-      }
-
+ 
       strcpy(wdirname,dirname);
-      gravatmp_hora(wdirname,accuser,accdia,acchora,accelap,accbytes,indexonly);
+      criatmp(user,tmp,debug,indexonly);
+      criatmp_hora(user,tmp,indexonly);
+   
+      ttopen=0;
+      bzero(html_old, MAXLEN);
+   
+      while(fgets(buf,sizeof(buf),fp_in)!=NULL) {
+         getword(accdia,buf,' ');
+         getword(acchora,buf,' ');
+         getword(accuser,buf,' ');
+         getword(accip,buf,' ');
+         getword(accurl,buf,' ');
+         getword(accbytes,buf,' ');
+         getword(acccode,buf,' ');
+         getword(accelap,buf,' ');
+         getword(accsmart,buf,' ');
+         getword(accsmart,buf,'"');
+   
+         if(strlen(accsmart) > 0) {
+            smartfilter++;
+            strcpy(wdirname,dirname);
+            grava_SmartFilter(wdirname,accuser,accip,accdia,acchora,accurl,accsmart);
+         }
 
-      if(iprel){
+         if(strcmp(Ip2Name,"yes") == 0) {
+            if(strcmp(accip,ipantes) != 0) {
+               strcpy(ipantes,accip);
+               ip2name(accip);
+               strcpy(nameantes,accip);
+            } else strcpy(accip,nameantes);
+         }
+     
          strcpy(wdirname,dirname);
-         gravaporuser(accuser,wdirname,accurl,accip,accdia,acchora,accbytes,accelap,indexonly);
-      }
+         gravatmp_hora(wdirname,accuser,accdia,acchora,accelap,accbytes,indexonly);
 
-      if(!rtotal){
-         strcpy(oldurl,accurl);
-         strcpy(oldacccode,acccode);
-         strcpy(oldaccelap,accelap);
-         strcpy(oldaccuser,accuser);
-         strcpy(oldaccip,accip);
-         strcpy(oldaccdia,accdia);
-         strcpy(oldacchora,acchora);
-         rtotal++;
-      }
+         if(iprel){
+            strcpy(wdirname,dirname);
+            gravaporuser(accuser,wdirname,accurl,accip,accdia,acchora,accbytes,accelap,indexonly);
+         }
 
-      if(site[0] != '\0') {
-         if(strcmp(oldaccuser,accuser) != 0){
-            strcpy(oldmsg,"OK");
-            if(strstr(oldacccode,"DENIED") != 0)
-               sprintf(oldmsg,"%s",text[46]);
-            strcpy(wdirname,dirname);
-            gravatmp(oldaccuser,wdirname,oldurl,nacc,nbytes,oldmsg,nelap,indexonly,incache,oucache);
-            strcpy(wdirname,dirname);
-            gravager(wdirname,oldaccuser,nacc,oldurl,nbytes,oldaccip,oldacchora,oldaccdia,nelap,incache,oucache);
-            nacc=0;
-            nbytes=0;
-            nelap=0;
-            incache=0;
-            oucache=0;
+         if(!rtotal){
+            strcpy(oldurl,accurl);
+            strcpy(oldacccode,acccode);
+            strcpy(oldaccelap,accelap);
+            strcpy(oldaccuser,accuser);
+            strcpy(oldaccip,accip);
+            strcpy(oldaccdia,accdia);
+            strcpy(oldacchora,acchora);
+            rtotal++;
          }
-      } else {     
-         if(strcmp(oldurl,accurl) != 0 || strcmp(oldaccuser,accuser) != 0){
-            strcpy(oldmsg,"OK");
-            if(strstr(oldacccode,"DENIED") != 0)
+
+         if(site[0] != '\0') {
+            if(strcmp(oldaccuser,accuser) != 0){
+               strcpy(oldmsg,"OK");
+               if(strstr(oldacccode,"DENIED") != 0)
                sprintf(oldmsg,"%s",text[46]);
-            strcpy(wdirname,dirname);
-            gravatmp(oldaccuser,wdirname,oldurl,nacc,nbytes,oldmsg,nelap,indexonly,incache,oucache);
-            strcpy(wdirname,dirname);
-            gravager(wdirname,oldaccuser,nacc,oldurl,nbytes,oldaccip,oldacchora,oldaccdia,nelap,incache,oucache);
-            nacc=0;
-            nbytes=0;
-            nelap=0;
-            incache=0;
-            oucache=0;
-	    if(strcmp(oldaccuser,accuser) != 0)
-	       ind2=0;
-         }
+               strcpy(wdirname,dirname);
+               gravatmp(oldaccuser,wdirname,oldurl,nacc,nbytes,oldmsg,nelap,indexonly,incache,oucache);
+               strcpy(wdirname,dirname);
+               gravager(wdirname,oldaccuser,nacc,oldurl,nbytes,oldaccip,oldacchora,oldaccdia,nelap,
+				incache,oucache);
+               nacc=0;
+               nbytes=0;
+               nelap=0;
+               incache=0;
+               oucache=0;
+            }
+         } else {     
+            if(strcmp(oldurl,accurl) != 0 || strcmp(oldaccuser,accuser) != 0){
+               strcpy(oldmsg,"OK");
+               if(strstr(oldacccode,"DENIED") != 0)
+                  sprintf(oldmsg,"%s",text[46]);
+               strcpy(wdirname,dirname);
+               gravatmp(oldaccuser,wdirname,oldurl,nacc,nbytes,oldmsg,nelap,indexonly,incache,oucache);
+               strcpy(wdirname,dirname);
+               gravager(wdirname,oldaccuser,nacc,oldurl,nbytes,oldaccip,oldacchora,oldaccdia,nelap,incache,oucache);
+               nacc=0;
+               nbytes=0;
+               nelap=0;
+               incache=0;
+               oucache=0;
+   	    if(strcmp(oldaccuser,accuser) != 0)
+   	       ind2=0;
+            }
       }
       nacc++;
       nbytes+=my_atoll(accbytes);
@@ -170,12 +187,19 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
                   str[z1]='_';
 	       if(str[z1]==':')
                   str[z1]='_';
+	       if(str[z1]=='/')
+                  str[z1]='_';
                siteind[z2]=str[z1];
                z2++;
             }
 	    sprintf(arqtt,"%s/tt%s-%s.html",dirname,accuser,siteind);
+            if(strlen(arqtt) > 255) {
+               strncpy(val7,arqtt,255);
+               bzero(arqtt,MAXLEN);
+               strcpy(arqtt,val7);
+            }            
             if ((fp_tt = fopen(arqtt, "w")) == 0) {
-               fprintf(stderr, "SARG: (html) %s: %s\n",text[45],arqtt);
+               fprintf(stderr, "SARG: (report) %s: %s\n",text[45],arqtt);
                exit(1);
             }
 	    ttopen=1;
@@ -270,6 +294,11 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
       strcpy(oldacchora,acchora);
 
    }
+ 
+   bzero(user,MAXLEN);
+   fclose(fp_in);
+   unlink(tmp3);
+}
 
    strcpy(oldmsg,"OK");
    if(strstr(oldacccode,"DENIED") != 0)
@@ -280,16 +309,17 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
    gravager(wdirname,oldaccuser,nacc,oldurl,nbytes,oldaccip,oldacchora,oldaccdia,nelap,incache,oucache);
    strcpy(wdirname,dirname);
    totaliza_day(wdirname,oldaccuser,indexonly);
- 
-   fclose(fp_in);
 
-   strcpy(wdirname,dirname);
-   tmpsort(wdirname, debug, TempDir, TopuserSortField, UserSortField, TopuserSortOrder, UserSortOrder, indexonly);
+   tmpsort(tmp, dirname, debug, TempDir, TopuserSortField, UserSortField, TopuserSortOrder, UserSortOrder, indexonly);
 
    strcpy(wdirname,dirname);
    totalger(wdirname, debug, outdir);
 
    if(strlen(email) == 0) {
+      if(strlen(SquidGuardLogPath) > 0) {
+         strcpy(wdirname,dirname);
+         squidguard_log(wdirname, debug, outdir, userip, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, Ip2Name, TopuserSortField, TopuserSortOrder, UserAgentLog, DateFormat);
+      }
       strcpy(wdirname,dirname);
       topuser(wdirname, debug, outdir, userip, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, Ip2Name, TopuserSortField, TopuserSortOrder, UserAgentLog, DateFormat, smartfilter);
 
@@ -314,6 +344,13 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
          smartfilter_report(wdirname, debug, outdir, userip, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, Ip2Name, TopuserSortField, TopuserSortOrder, UserAgentLog, DateFormat);
       }
 
+      if(strlen(SquidGuardLogPath) > 0) {
+//         strcpy(wdirname,dirname);
+//         squidguard_log(wdirname, debug, outdir, userip, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, Ip2Name, TopuserSortField, TopuserSortOrder, UserAgentLog, DateFormat);
+         strcpy(wdirname,dirname);
+         squidguard_report(wdirname, debug, outdir, userip, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, Ip2Name, TopuserSortField, TopuserSortOrder, UserAgentLog, DateFormat);
+      }
+
       if(strstr(ReportType,"users_sites") != 0) {
          strcpy(wdirname,dirname);
          htmlrel(wdirname, debug, iprel, userip, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, UserSortField, UserSortOrder, DateFormat, indexonly, PerUserLimitFile, PerUserLimit, Ip2Name);
