@@ -1,6 +1,6 @@
 /*
  * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@onda.com.br
+ * Mar/98 - Pedro L Orso - orso@brturbo.com
  */
 
 #include "include/conf.h"
@@ -150,9 +150,11 @@ void siteuser(const char *dirname, int debug, const char *outdir, int userip, ch
 
    fputs("</table></center>\n",fp_ou);
 
-   zdate(ftime, DateFormat);
-   sprintf(ourl,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
-   fputs(ourl,fp_ou);
+   if(strcmp(ShowSargInfo,"yes") == 0) {
+      zdate(ftime, DateFormat);
+      sprintf(ourl,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
+      fputs(ourl,fp_ou);
+   }
 
    fputs("</html>\n",fp_ou);
    
