@@ -1,6 +1,6 @@
 /*
  * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@onda.com.br
+ * Mar/98 - Pedro L Orso - orso@brturbo.com
  */
 
 #include "include/conf.h"
@@ -121,9 +121,11 @@ void smartfilter_report(const char *dirname, int debug, const char *outdir, int
          if(fuser) {
             fuser=0;
             fputs("</table>\n",fp_user);
-            zdate(ftime, DateFormat);
-            sprintf(html2,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
-            fputs(html2,fp_user);
+            if(strcmp(ShowSargInfo,"yes") == 0) {
+               zdate(ftime, DateFormat);
+               sprintf(html2,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
+               fputs(html2,fp_user);
+	    }
             fputs("</html>\n",fp_user);
             fclose(fp_user);
          }
@@ -173,19 +175,22 @@ void smartfilter_report(const char *dirname, int debug, const char *outdir, int
 
    fputs("</table>\n",fp_ou);
 
-   zdate(ftime, DateFormat);
-   sprintf(html,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",text[108],URL,PGM
-,VERSION,text[109],ftime);
-   fputs(html,fp_ou);
+   if(strcmp(ShowSargInfo,"yes") == 0) {
+      zdate(ftime, DateFormat);
+      sprintf(html,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
+      fputs(html,fp_ou);
+   }
 
    fputs("</html>\n",fp_ou);
 
    fclose(fp_ou);
    if(fp_user) {
       fputs("</table>\n",fp_user);
-      zdate(ftime, DateFormat);
-      sprintf(html2,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
-      fputs(html2,fp_user);
+      if(strcmp(ShowSargInfo,"yes") == 0) {
+         zdate(ftime, DateFormat);
+         sprintf(html2,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
+         fputs(html2,fp_user);
+      }
       fputs("</html>\n",fp_user);
       fclose(fp_user);
    }
