@@ -1,12 +1,11 @@
 /*
  * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@onda.com.br
+ * Mar/98 - Pedro L Orso - orso@brturbo.com
  */
 
 #include "include/conf.h"
 
-
-void tmpsort(const char *dirname, int debug, char *TempDir, char *TopuserSortField, char *UserSortField, char *TopuserSortOrder, char *UserSortOrder, int indexonly)
+void tmpsort(char *tmp, const char *dirname, int debug, char *TempDir, char *TopuserSortField, char *UserSortField, char *TopuserSortOrder, char *UserSortOrder, int indexonly)
 {
 
    DIR *dirp;
@@ -26,7 +25,7 @@ void tmpsort(const char *dirname, int debug, char *TempDir, char *TopuserSortFie
    wnome[0]='\0';
    wnome2[0]='\0';
 
-   dirp = opendir(dirname);
+   dirp = opendir(tmp);
    while ( (direntp = readdir( dirp )) != NULL ){
       if(strstr(direntp->d_name,".tmp") == 0)
          continue;
@@ -80,12 +79,54 @@ void tmpsort(const char *dirname, int debug, char *TempDir, char *TopuserSortFie
         
       strcat(arqou,".txt");
       sprintf(csort,"sort -n -T %s %s -k %s -k %s -k %s -o %s %s",TempDir,order,field1,field2,field3,arqou,arqin);
-
       system(csort);
-
       unlink(arqin);
 
    }
+
    (void)closedir( dirp );
+   (void)rewinddir( dirp );
+   return;
+}
+
+void sort_users_log(char *tmp, int debug)
+{
+
+   DIR *dirp;
+   struct dirent *direntp;
+   char csort[MAXLEN];
+   char wtmp[MAXLEN];
+   char wname2[MAXLEN];
+   char wdname[MAXLEN];
+
+   sprintf(wtmp,"%s/sarg",tmp);
+
+   dirp = opendir(wtmp);
+   while ( (direntp = readdir( dirp )) != NULL ){
+      if(strstr(direntp->d_name,".unsort") == 0)
+         continue;
+      strcpy(wdname,direntp->d_name);
+
+      bzero(user, MAXLEN);
+      strip_unsort:
+      getword(wname2,wdname,'.');
+      strcat(user,wname2);
+
+      if(strcmp(wdname,"unsort") !=0) {
+         strcat(user,".");
+         goto strip_unsort;
+      }
+
+      sprintf(csort,"sort -T %s -k 5,5 -k 1,1 -k 2,2 -o %s/%s.log %s/%s.unsort", 
+					tmp, wtmp, user, wtmp, user);
+      system(csort);
+      sprintf(wdname,"%s/%s.unsort",wtmp,user);
+      unlink(wdname);
+      bzero(user, MAXLEN);
+
+   }
+   (void)closedir( dirp );
+   (void)rewinddir( dirp );
+
    return;
 }
