@@ -1,6 +1,6 @@
 /*
  * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@onda.com.br
+ * Mar/98 - Pedro L Orso - orso@brturbo.com
  */
 
 #include "include/conf.h"
@@ -246,6 +246,11 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
       fputs(preg,fp_top3);
    }
 
+   if(squidguard_count) {
+     sprintf(preg,"<tr><td colspan=11><font size=-1><a href=\"squidguard.html\">%s</a> %s</font></td></tr>\n",text[122],text[55]);
+     fputs(preg,fp_top3);
+   }
+
    if(denied_count) {
       sprintf(preg,"<tr><td colspan=11><font size=-1><a href=\"denied.html\">%s</a> %s</font></td></tr>\n",text[118],text[55]);
       fputs(preg,fp_top3);
@@ -272,18 +277,60 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
    strcpy(val6,text[94]);
    strcpy(val7,text[95]);
    sprintf(val8,"%%%s",text[99]);
+   strcpy(val9,"colspan=2");
+   bzero(val10, 255);
+ 
+   strcpy(hbc1,HeaderBgColor);
+   strcpy(hbc2,HeaderBgColor);
+   strcpy(hbc3,HeaderBgColor);
+   strcpy(hbc4,HeaderBgColor);
+   strcpy(hbc5,HeaderBgColor);
+   strcpy(hbc6,HeaderBgColor);
+   strcpy(hbc7,HeaderBgColor);
+   strcpy(hbc8,HeaderBgColor);
+   strcpy(hbc9,HeaderBgColor);
+   strcpy(hbc10,HeaderBgColor);
 
-   if(strstr(TopUserFields,"NUM") == 0)		 bzero(val1, 255);
-   if(strstr(TopUserFields,"USERID") == 0)	 bzero(val2, 255);
-   if(strstr(TopUserFields,"CONNECT") == 0)	 bzero(val3, 255);
-   if(strstr(TopUserFields,"BYTES") == 0)	 bzero(val4, 255);
-   if(strstr(TopUserFields,"SETYB") == 0)	 bzero(val11, 255);
-   if(strstr(TopUserFields,"IN-CACHE-OUT") == 0) bzero(val5, 255);
-   if(strstr(TopUserFields,"USED_TIME") == 0) 	 bzero(val6, 255);
-   if(strstr(TopUserFields,"MILISEC") == 0) 	 bzero(val7, 255);
-   if(strstr(TopUserFields,"TIME") == 0) 	 bzero(val8, 255);
+   if(strstr(TopUserFields,"NUM") == 0) {
+      bzero(val1, 255);
+      bzero(hbc1, 30);
+   }
+   if(strstr(TopUserFields,"USERID") == 0) {
+      bzero(val2, 255);
+      bzero(hbc2, 30);
+   }
+   if(strstr(TopUserFields,"CONNECT") == 0) {
+      bzero(val3, 255);
+      bzero(hbc3, 30);
+   }
+   if(strstr(TopUserFields,"BYTES") == 0) {
+      bzero(val4, 255);
+      bzero(hbc4, 30);
+   }
+   if(strstr(TopUserFields,"SETYB") == 0) {
+      bzero(val11, 255);
+      bzero(hbc9, 30);
+   }
+   if(strstr(TopUserFields,"IN-CACHE-OUT") == 0) {
+      bzero(val5, 255);
+      bzero(hbc5, 30);
+      bzero(val9, 255);
+      strcpy(val10,"<td></td>");
+   }
+   if(strstr(TopUserFields,"USED_TIME") == 0) {
+      bzero(val6, 255);
+      bzero(hbc6, 30);
+   }
+   if(strstr(TopUserFields,"MILISEC") == 0) { 
+      bzero(val7, 255);
+      bzero(hbc7, 30);
+   }
+   if(strstr(TopUserFields,"%TIME") == 0) {
+      bzero(val8, 255);
+      bzero(hbc8, 30);
+   }
 
-   sprintf(preg,"<tr><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s></font></th><th align=left bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s colspan=2><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th></tr>\n",HeaderBgColor,FontSize,HeaderColor,val1,HeaderBgColor,FontSize,HeaderColor,HeaderBgColor,FontSize,HeaderColor,val2,HeaderBgColor,FontSize,HeaderColor,val3,HeaderBgColor,FontSize,HeaderColor,val4,HeaderBgColor,FontSize,HeaderColor,val11,HeaderBgColor,FontSize,HeaderColor,val5,HeaderBgColor,FontSize,HeaderColor,val6,HeaderBgColor,FontSize,HeaderColor,val7,HeaderBgColor,FontSize,HeaderColor,val8);
+   sprintf(preg,"<tr><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s></font></th><th align=left bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s %s><font size=%s color=%s>%s</font>%s</th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th></tr>\n",hbc1,FontSize,HeaderColor,val1,hbc1,FontSize,HeaderColor,hbc2,FontSize,HeaderColor,val2,hbc3,FontSize,HeaderColor,val3,hbc4,FontSize,HeaderColor,val4,hbc9,FontSize,HeaderColor,val11,hbc5,val9,FontSize,HeaderColor,val5,val10,hbc6,FontSize,HeaderColor,val6,hbc7,FontSize,HeaderColor,val7,hbc8,FontSize,HeaderColor,val8);
 
    fputs(preg,fp_top3);
 
@@ -398,22 +445,64 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
       sprintf(val6,"%s",buildtime(tnelap));
       sprintf(val7,"%3.2f%%",perc2);
 
-      if(strstr(TopUserFields,"NUM") == 0)          	bzero(val1, 255);
-      if(strstr(TopUserFields,"USERID") == 0)		bzero(val2, 255);
-      if(strstr(TopUserFields,"CONNECT") == 0)	 	bzero(wwork1, 255);
-      if(strstr(TopUserFields,"BYTES") == 0)	 	bzero(wwork2, 255);
-      if(strstr(TopUserFields,"SETYB") == 0)	 	bzero(val3, 255);
-      if(strstr(TopUserFields,"IN-CACHE-OUT") == 0) 	bzero(val4, 255);
-      if(strstr(TopUserFields,"IN-CACHE-OUT") == 0) 	bzero(val5, 255);
-      if(strstr(TopUserFields,"USED_TIME") == 0) 	bzero(val6, 255);
-      if(strstr(TopUserFields,"MILISEC") == 0) 	 	bzero(wwork3, 255);
-      if(strstr(TopUserFields,"TIME") == 0) 	 	bzero(val7, 255);
-      if(strstr(ReportType,"users_sites") == 0)         href[0]='\0';
+      strcpy(hbc1,TxBgColor);
+      strcpy(hbc2,TxBgColor);
+      strcpy(hbc3,TxBgColor);
+      strcpy(hbc4,TxBgColor);
+      strcpy(hbc5,TxBgColor);
+      strcpy(hbc6,TxBgColor);
+      strcpy(hbc7,TxBgColor);
+      strcpy(hbc8,TxBgColor);
+      strcpy(hbc9,TxBgColor);
+      strcpy(hbc10,TxBgColor);
 
-      sprintf(preg,"<tr><td align=right border=0 bgcolor=%s><font size=%s>%s</font></td><td bgcolor=%s><font size=%s>%s</font></td><td bgcolor=%s><font size=%s>%s%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=center bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font><td align=right bgcolor=%s><font size=%s>%s</font></td></tr>\n",TxBgColor,FontSize,val1,TxBgColor,FontSize,val2,TxBgColor,FontSize,href,name,TxBgColor,FontSize,wwork1,TxBgColor,FontSize,wwork2,TxBgColor,FontSize,val3,TxBgColor,FontSize,val4,TxBgColor,FontSize,val5,TxBgColor,FontSize,val6,TxBgColor,FontSize,wwork3,TxBgColor,FontSize,val7);
+      if(strstr(TopUserFields,"NUM") == 0) {
+         bzero(val1, 255);
+         bzero(hbc1, 30);
+      }
+      if(strstr(TopUserFields,"USERID") == 0) {
+         bzero(val2, 255);
+         bzero(hbc2, 30);
+      }
+      if(strstr(TopUserFields,"CONNECT") == 0) {
+         bzero(wwork1, 255);
+         bzero(hbc3, 30);
+      }
+      if(strstr(TopUserFields,"BYTES") == 0) { 
+         bzero(wwork2, 255);
+         bzero(hbc4, 30);
+      }
+      if(strstr(TopUserFields,"SETYB") == 0) {
+         bzero(val3, 255);
+         bzero(hbc5, 30);
+      }
+      if(strstr(TopUserFields,"IN-CACHE-OUT") == 0) {
+         bzero(val4, 255);
+         bzero(hbc6, 30);
+      }
+      if(strstr(TopUserFields,"IN-CACHE-OUT") == 0) {
+         bzero(val5, 255);
+         bzero(hbc7, 30);
+      }
+      if(strstr(TopUserFields,"USED_TIME") == 0) {
+         bzero(val6, 255);
+         bzero(hbc8, 30);
+      }
+      if(strstr(TopUserFields,"MILISEC") == 0) {
+         bzero(wwork3, 255);
+         bzero(hbc9, 30);
+      }
+      if(strstr(TopUserFields,"%TIME") == 0) {
+         bzero(val7, 255);
+         bzero(hbc10, 30);
+      }
 
-      if(strstr(user,"TOTAL") != 0){
+      if(strstr(ReportType,"users_sites") == 0)
+         href[0]='\0';
 
+      sprintf(preg,"<tr><td align=right border=0 bgcolor=%s><font size=%s>%s</font></td><td bgcolor=%s><font size=%s>%s</font></td><td bgcolor=%s><font size=%s>%s%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=center bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font><td align=right bgcolor=%s><font size=%s>%s</font></td></tr>\n",hbc1,FontSize,val1,hbc2,FontSize,val2,TxBgColor,FontSize,href,name,hbc3,FontSize,wwork1,hbc4,FontSize,wwork2,hbc5,FontSize,val3,hbc6,FontSize,val4,hbc7,FontSize,val5,hbc8,FontSize,val6,hbc9,FontSize,wwork3,hbc10,FontSize,val7);
+
+      if(strstr(user,"TOTAL") != 0) {
 	 strcpy(preg,"<tr><td></td></tr><tr><td></td></tr>");
          fputs(preg,fp_top3);
 
@@ -431,11 +520,50 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
 	 sprintf(wwork2,"%s",fixnum(ttnbytes));
 	 sprintf(wwork3,"%s",fixnum(ttnelap));
 
+         strcpy(hbc1,HeaderBgColor);
+         strcpy(hbc2,HeaderBgColor);
+         strcpy(hbc3,HeaderBgColor);
+         strcpy(hbc4,HeaderBgColor);
+         strcpy(hbc5,HeaderBgColor);
+         strcpy(hbc6,HeaderBgColor); 
+         strcpy(hbc7,HeaderBgColor);
+         strcpy(hbc8,HeaderBgColor);
+         strcpy(hbc9,HeaderBgColor);
+         strcpy(hbc10,HeaderBgColor);
+
+         sprintf(val4,"%3.2f%%",inperc);
+         sprintf(val5,"%3.2f%%",ouperc);
+         sprintf(val6,"%s",buildtime(ttnelap));
+         sprintf(val7,"%3.2f%%",perc2);
+
+         if(strstr(TopUserFields,"CONNECT") == 0) {
+            bzero(wwork1, 255);
+            bzero(hbc1, 30);
+         }
+         if(strstr(TopUserFields,"BYTES") == 0) {
+            bzero(wwork2, 255);
+            bzero(hbc2, 30);
+         }
+         if(strstr(TopUserFields,"IN-CACHE-OUT") == 0) {
+            bzero(val4, 255);
+            bzero(val5, 255);
+            bzero(hbc3, 30);
+            bzero(hbc4, 30);
+         }
+         if(strstr(TopUserFields,"USED_TIME") == 0) {
+            bzero(val6, 255);
+            bzero(hbc5, 30);
+         }
+         if(strstr(TopUserFields,"MILISEC") == 0) {
+            bzero(wwork3, 255);
+            bzero(hbc6, 30);
+         }
+
          if(strstr(ReportType,"date_time") != 0) {
 	    if(strstr(TopUserFields,"TOTAL") != 0)
-               sprintf(preg,"<tr><td></td><th align=left bgcolor=%s><font size=%s color=%s>%s</th><td></td><th align=right bgcolor=%s><font size=%s color=%s>%s</th><th align=right bgcolor=%s><font size=%s color=%s>%15s</th><td></td><th align=right bgcolor=%s><font size=%s color=%s>%3.2f%%</th><th align=left bgcolor=%s><font size=%s color=%s>%3.2f%%</th><th align=center bgcolor=%s><font size=%s color=%s>%s</th><th align=right bgcolor=%s><font size=%s color=%s>%s</th></tr>\n",HeaderBgColor,FontSize,HeaderColor,text[107],HeaderBgColor,FontSize,HeaderColor,wwork1,HeaderBgColor,FontSize,HeaderColor,wwork2,HeaderBgColor,FontSize,HeaderColor,inperc,HeaderBgColor,FontSize,HeaderColor,ouperc,HeaderBgColor,FontSize,HeaderColor,buildtime(ttnelap),HeaderBgColor,FontSize,HeaderColor,wwork3);
+               sprintf(preg,"<tr><td></td><th align=left bgcolor=%s><font size=%s color=%s>%s</th><td></td><th align=right bgcolor=%s><font size=%s color=%s>%s</th><th align=right bgcolor=%s><font size=%s color=%s>%15s</th><td></td><th align=right bgcolor=%s><font size=%s color=%s>%s</th><th align=left bgcolor=%s><font size=%s color=%s>%s</th><th align=center bgcolor=%s><font size=%s color=%s>%s</th><th align=right bgcolor=%s><font size=%s color=%s>%s</th></tr>\n",HeaderBgColor,FontSize,HeaderColor,text[107],hbc1,FontSize,HeaderColor,wwork1,hbc2,FontSize,HeaderColor,wwork2,hbc3,FontSize,HeaderColor,val4,hbc4,FontSize,HeaderColor,val5,hbc5,FontSize,HeaderColor,val6,hbc6,FontSize,HeaderColor,wwork3);
 	 } else if(strstr(TopUserFields,"TOTAL") != 0)
-            sprintf(preg,"<tr><td></td><td></td><th align=left bgcolor=%s><font size=%s color=%s>%s</th><th align=right bgcolor=%s><font size=%s color=%s>%s</th><th align=right bgcolor=%s><font size=%s color=%s>%15s</th><td></td><th align=right bgcolor=%s><font size=%s color=%s>%3.2f%%</th><th align=left bgcolor=%s><font size=%s color=%s>%3.2f%%</th><th align=center bgcolor=%s><font size=%s color=%s>%s</th><th align=right bgcolor=%s><font size=%s color=%s>%s</th></tr>\n",HeaderBgColor,FontSize,HeaderColor,text[107],HeaderBgColor,FontSize,HeaderColor,wwork1,HeaderBgColor,FontSize,HeaderColor,wwork2,HeaderBgColor,FontSize,HeaderColor,inperc,HeaderBgColor,FontSize,HeaderColor,ouperc,HeaderBgColor,FontSize,HeaderColor,buildtime(ttnelap),HeaderBgColor,FontSize,HeaderColor,wwork3);
+            sprintf(preg,"<tr><td></td><td></td><th align=left bgcolor=%s><font size=%s color=%s>%s</th><th align=right bgcolor=%s><font size=%s color=%s>%s</th><th align=right bgcolor=%s><font size=%s color=%s>%15s</th><td></td><th align=right bgcolor=%s><font size=%s color=%s>%s</th><th align=left bgcolor=%s><font size=%s color=%s>%s</th><th align=center bgcolor=%s><font size=%s color=%s>%s</th><th align=right bgcolor=%s><font size=%s color=%s>%s</th></tr>\n",HeaderBgColor,FontSize,HeaderColor,text[107],hbc1,FontSize,HeaderColor,wwork1,hbc2,FontSize,HeaderColor,wwork2,hbc3,FontSize,HeaderColor,val4,hbc4,FontSize,HeaderColor,val5,hbc5,FontSize,HeaderColor,val6,hbc6,FontSize,HeaderColor,wwork3);
 
       }
 
@@ -461,13 +589,13 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
    sprintf(wwork2,"%s",fixnum(tnbytes));
    sprintf(wwork3,"%s",fixnum(twork2));
 
-   if((strstr(ReportType,"date_time") && strstr(TopUserFields,"AVERAGE") != 0))
+   if((strstr(ReportType,"date_time") != 0 && strstr(TopUserFields,"AVERAGE") != 0)) {
       sprintf(preg,"<tr><th></th><th align=left bgcolor=%s><font size=%s color=%s>%s</font></th><th></th><th align=right bgcolor=%s><font size=%s color=%s>%s</font></th><th align=right bgcolor=%s><font size=%s color=%s>%15s</font></th><td></td><td></td><td></td><th align=center bgcolor=%s><font size=%s color=%s>%s</font></th><th align=right bgcolor=%s><font size=%s color=%s>%s</font></th></tr>\n",HeaderBgColor,FontSize,HeaderColor,text[96],HeaderBgColor,FontSize,HeaderColor,wwork1,HeaderBgColor,FontSize,HeaderColor,wwork2,HeaderBgColor,FontSize,HeaderColor,buildtime(ttnelap/totuser),HeaderBgColor,FontSize,HeaderColor,wwork3);
-   else
-      if(strstr(TopUserFields,"AVERAGE") != 0) {
-         sprintf(preg,"<tr><th><td></td></th><th align=left bgcolor=%s><font size=%s color=%s>%s</font></th><th align=right bgcolor=%s><font size=%s color=%s>%s</font></th><th align=right bgcolor=%s><font size=%s color=%s>%15s</font></th><td></td><td></td><td></td><th align=center bgcolor=%s><font size=%s color=%s>%s</font></th><th align=right bgcolor=%s><font size=%s color=%s>%s</font></th></tr>\n",HeaderBgColor,FontSize,HeaderColor,text[96],HeaderBgColor,FontSize,HeaderColor,wwork1,HeaderBgColor,FontSize,HeaderColor,wwork2,HeaderBgColor,FontSize,HeaderColor,buildtime(ttnelap/totuser),HeaderBgColor,FontSize,HeaderColor,wwork3);
+      fputs(preg,fp_top3);
+    } else if(strstr(TopUserFields,"AVERAGE") != 0) {
+         sprintf(preg,"<tr><th></th><td></td><th align=left bgcolor=%s><font size=%s color=%s>%s</font></th><th align=right bgcolor=%s><font size=%s color=%s>%s</font></th><th align=right bgcolor=%s><font size=%s color=%s>%15s</font></th><td></td><td></td><td></td><th align=center bgcolor=%s><font size=%s color=%s>%s</font></th><th align=right bgcolor=%s><font size=%s color=%s>%s</font></th></tr>\n",HeaderBgColor,FontSize,HeaderColor,text[96],HeaderBgColor,FontSize,HeaderColor,wwork1,HeaderBgColor,FontSize,HeaderColor,wwork2,HeaderBgColor,FontSize,HeaderColor,buildtime(ttnelap/totuser),HeaderBgColor,FontSize,HeaderColor,wwork3);
          fputs(preg,fp_top3);
-      }
+   }
 
    if(strlen(UserAgentLog) > 0) {
       fputs("<tr><td></td></tr>\n",fp_top3);
@@ -478,9 +606,11 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
    strcpy(preg,"</table></center>");
    fputs(preg,fp_top3);
 
-   zdate(ftime, DateFormat);
-   sprintf(html,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
-   fputs(html,fp_top3);
+   if(strcmp(ShowSargInfo,"yes") == 0) {
+     zdate(ftime, DateFormat);
+     sprintf(html,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
+     fputs(html,fp_top3);
+   }
 
 final:
    fclose(fp_top1);
