@@ -1,6 +1,6 @@
 /*
  * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@onda.com.br
+ * Mar/98 - Pedro L Orso - orso@brturbo.com
  */
 
 #include "include/conf.h"
@@ -269,9 +269,11 @@ void useragent(const char *dirname, int debug, const char *outdir, char *TempDir
    }
 
    fputs("</table></html>\n",fp_ht);
-   zdate(ftime, DateFormat);
-   sprintf(html,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
-   fputs(html,fp_ht);
+   if(strcmp(ShowSargInfo,"yes") == 0) {
+      zdate(ftime, DateFormat);
+      sprintf(html,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
+      fputs(html,fp_ht);
+   }
 
    fclose(fp_in);
    fclose(fp_ht);
