@@ -125,6 +125,39 @@ void builddia(char *dia, char *mes, char *ano, char *df, char *wdata)
 }
 
 
+void buildymd(char *dia, char *mes, char *ano, char *wdata)
+{
+   char nmes[3];
+   int  x;
+
+   nmes[0]='\0';
+
+   for(x=0; x<=12; x++) {
+      if(strcmp(mtab1[x],mes) == 0)
+         strcpy(nmes,mtab2[x]);
+   }
+
+   sprintf(wdata,"%s%s%s",ano,nmes,dia);
+
+   return;
+
+}
+
+
+void conv_month(char *month)
+{
+   int  x;
+
+   for(x=0; x<=12; x++) {
+      if(strcmp(mtab1[x],month) == 0)
+         strcpy(month,mtab2[x]);
+   }
+
+   return;
+
+}
+
+
 void fixper(char *tbuf, char *periodo, char *duntil)
 {
 
@@ -212,12 +245,42 @@ char *fixnum(long long int inteiro)
    char *pbuf;
    char ret[MAXIMO * 2];
    char *pret;
+   float perc=0;
    register int i, j, k;
-
+   static char abbrev[30];
+      
    my_lltoa(inteiro, num, 0);
 
-   for(i=0;i<MAXIMO*2;i++)
-   buf[i]='\0';
+   if(strcmp(DisplayedValues,"abbreviation") == 0) {
+      if(inteiro < 1000) {
+         perc=inteiro;
+         sprintf(abbrev,"%3.0f",perc);
+      }
+      if(inteiro > 999 && inteiro <= 999999) {
+         perc=inteiro / 1000;
+         if((inteiro % 1000) >= 500) perc++;
+         sprintf(abbrev,"%3.0f K",perc);
+      }
+      if(inteiro >999999 && inteiro <= 999999999) {
+         perc=inteiro / 1000000;
+         if((inteiro % 1000000) >= 500) perc++;
+         sprintf(abbrev,"%3.0f M",perc);
+      }
+      if(inteiro > 999999999 && inteiro <= 999999999999) {
+         perc=inteiro / 1000000000;
+         if((inteiro % 1000000000) >= 500) perc++;
+         sprintf(abbrev,"%3.0f G",perc);
+      }
+      if(inteiro > 999999999999) {
+         perc=inteiro / 1000000000000;
+         if((inteiro % 1000000000000) >= 500) perc++;
+         sprintf(abbrev,"%3.0f T",perc);
+      }
+
+      return(abbrev);
+   }
+
+   bzero(buf, MAXIMO*2);
 
    pbuf = buf;
    pret = ret;
@@ -362,7 +425,6 @@ void obttotal(char *dirname, char *name, char *tbytes, char *tuser, char *media)
    if(tuser[0] == '\0') {
       wtuser=0;
       sprintf(media,"%s","0");
-      fclose(fp_in);
       return;
    }
    
@@ -611,6 +673,7 @@ char *subs(char *str, char *from, char *to)
     return (char *) ret;
 }
 
+
 void removetmp(char *outdir, int debug)
 {
 
@@ -709,3 +772,57 @@ int testvaliduserchar(char *user)
    }
    return 0;
 }
+
+int compar( const void *a, const void *b )
+{ if( *(int *)a > *(int *)b ) return 1;
+  if( *(int *)a < *(int *)b ) return -1;
+  return 0;
+}
+
+int getnumlist( char *buf, numlist *list, const int len, const int maxvalue )
+{ int i, j, d, flag, r1, r2;
+  char *pbuf, **bp, *strbufs[ 24 ];
+  
+  bp = strbufs;
+  strtok( buf, " \t" );
+  for( *bp = strtok( NULL, "," ), list->len = 0; *bp; *bp = strtok( NULL, "," ) )
+   { if( ++bp >= &strbufs[ 24 ] )
+       break;
+     list->len++;
+   }
+  if( ! list->len )      
+     return -1;
+  d = 0;
+  for( i = 0; i < list->len; i++ )  
+   { if( strstr( strbufs[ i ], "-" ) != 0 )
+      { pbuf = strbufs[ i ];
+        strtok( pbuf, "-" );
+        pbuf = strtok( NULL, "\0" );
+        r1 = atoi( strbufs[ i ] );
+        if( ( r2 = atoi( pbuf ) ) >= maxvalue || r1 >= r2 )
+          return -1;
+        if( i + d + ( r2 - r1 ) + 1 <= len )
+         { for( j = r1; j <= r2; j++ )
+             list->list[ i + d++ ] = j;
+           d--;
+         }
+      }
+     else
+       if( ( list->list[ i + d ] = atoi( strbufs[ i ] ) ) >= maxvalue )
+          return 1;
+   }
+  list->len += d;
+  qsort( list->list, list->len, sizeof( int ), compar );
+  do
+   { flag = 0;
+     for( i = 0; i < list->len - 1; i++ )
+       if( list->list[ i ] == list->list[ i + 1 ] )
+        { for( j = i + 1; j < list->len; j++ )
+            list->list[ j - 1 ] = list->list[ j ];
+          list->len--;
+          flag = 1;
+          break;
+        }
+   } while( flag );
+  return 0;
+}
